HandTrackingError class final

An unrecoverable error occurred (camera denied, model load failed, etc.).

No further HandTrackingTracking or HandTrackingLost events are emitted after this state.

Inheritance

Constructors

HandTrackingError(Object error)
const

Properties

error Object
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited